@@ -1,7 +1,7 @@
 package Log::Any::DBI::Query;
 
-our $DATE = '2016-02-11'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2016-02-19'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -29,7 +29,7 @@ sub _postcall_logger {
     #$log->tracef("D1: %s", $args->{name});
 
     my ($meth) = $args->{name} =~ /.+::(.+)/;
-    return if $meth =~ /\Aprepare\z/;
+    return if $meth =~ /\A(prepare|execute)\z/;
     $log->tracef("SQL result (%s): %s", $meth, $args->{result});
 }
 
@@ -51,7 +51,8 @@ sub import {
                 my $meth = shift;
                 return 1 if $log_query && $meth =~
                     /\A(
-                         DBI::db::(prepare|do|select.+)
+                         DBI::db::(prepare|do|select.+) |
+                         DBI::st::(execute)
                      )\z/x;
                 return 1 if $log_result && $meth =~
                     /\A(
@@ -82,7 +83,7 @@ Log::Any::DBI::Query - Log DBI queries (and results)
 
 =head1 VERSION
 
-This document describes version 0.05 of Log::Any::DBI::Query (from Perl distribution Log-Any-DBI-Query), released on 2016-02-11.
+This document describes version 0.06 of Log::Any::DBI::Query (from Perl distribution Log-Any-DBI-Query), released on 2016-02-19.
 
 =head1 SYNOPSIS
 
